package
Version:
v0.0.0-...-fcbf4c4
Opens a new window with list of versions in this module.
Published: Jun 22, 2024
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetConfig returns the configuration instance
type Config struct {
NameSystem string `yaml:"nameSystem"`
Version string `yaml:"version"`
Services map[interface{}]interface{} `yaml:"Services"`
}
ReadFile reads the configuration file
Source Files
¶
Click to show internal directories.
Click to hide internal directories.